<img width="300px" src="https://sickrage.ca/img/logo-stacked.png" />

# 

##Wed Aug 19 2020 06:12:58 GMT+0000 (Coordinated Universal Time)


## Bug Fixes
  - Fixed issue shutting down scheduler causing an exception which broke restart sequence
  ([afc00d10](https://gitlab-ci-token:xfV22JB2Y5xPrtZY4yyd@git.sickrage.ca/SiCKRAGE/sickrage/commit/afc00d10f9641ecd158b9be1ae8b05a6e26628ea))




